<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Print</name>
    <message>
        <source>&amp;Print</source>
        <translation type="obsolete">&amp;P 印刷</translation>
    </message>
    <message>
        <source>Print current drawing</source>
        <translation type="obsolete">現在の図面を印刷</translation>
    </message>
</context>
<context>
    <name>PrintCurrentView</name>
    <message>
        <location filename="../PrintCurrentViewInit.js" line="+2"/>
        <source>Print &amp;Current View</source>
        <translation>現在のビューを印刷</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Print current view</source>
        <translation>現在のビューを印刷</translation>
    </message>
</context>
</TS>
